@@ -1,5 +1,4 @@
 import sqlite3
-import os
 
 
 def setup():
@@ -57,15 +56,6 @@ def retrieve_urls(database_name):
     return urls
 
 
-def retrieve_attribute(attribute, url):
-    conn = sqlite3.connect('resources_for_testing/handy.sqlite')
-
-    c = conn.cursor()
-    urls = c.execute(f"SELECT {attribute} from urls_and_attributes where url='{url}'").fetchall()
-    conn.close()
-    return urls
-
-
 def add_url(url):
     conn = sqlite3.connect('resources_for_testing/handy.sqlite')
 
@@ -74,6 +64,7 @@ def add_url(url):
     conn.commit()
     conn.close()
 
+
 def delete_url(url):
     conn = sqlite3.connect('resources_for_testing/handy.sqlite')
 
@@ -82,33 +73,10 @@ def delete_url(url):
     conn.commit()
     conn.close()
 
-def save_attributes(url, ids, css_classes, input_names):
-    conn = sqlite3.connect('resources_for_testing/handy.sqlite')
 
-    #line below will return array of strings, instead of array of tuples
-    # conn.row_factory = lambda cursor, row: row[0]
-    print(ids)
-    temp_ids = repr(ids)
-    temp_css_classes = repr(css_classes)
-    temp_input_names = repr(input_names)
-    c = conn.cursor()
-    k = f'UPDATE urls_and_attributes set ids=\"{temp_ids}\", css_classes=\"{temp_css_classes}\", input_names=\"{temp_input_names}\" where url=\"{url}\"'
-    print(k)
-    c.execute(k)
-    conn.commit()
-    conn.close()
 def rename_url(url, new_url):
     conn = sqlite3.connect('resources_for_testing/handy.sqlite')
     c = conn.cursor()
     c.execute(f'UPDATE urls_and_attributes set url=\'{new_url}\' where url=\'{url}\'')
     conn.commit()
     conn.close()
-#
-# def path_to_database():
-#     print(os.path.dirname(os.path.realpath(__file__)))
-
-# c = database_retrieve_urls('urls_and_attributes')
-# print(c)
-# database_save_attributes("/spanie", ids=["less go"], css_classes=['cos innego'], input_names=['lecim', 'na', 'szczecin'])
-# retrieve_urls('da')
-# path_to_database()
\ No newline at end of file
